package com.caimei365.manager.controller.caimei.finance;

import com.caimei365.manager.entity.PaginationVo;
import com.caimei365.manager.entity.ResponseJson;
import com.caimei365.manager.entity.caimei.ReceiptDetail;
import com.caimei365.manager.entity.caimei.ReceiptList;
import com.caimei365.manager.entity.caimei.ReceiptParam;
import com.caimei365.manager.entity.caimei.ReceiptType;
import com.caimei365.manager.service.caimei.FinanceService;
import org.springframework.http.HttpHeaders;
import org.springframework.web.bind.annotation.*;

import javax.annotation.Resource;
import java.util.List;

/**
 * 财务管理接口
 *
 *
 * @author Charles
 */
@RestController
@RequestMapping("/finance")
public class FinanceApi {

    @Resource
    private FinanceService financeService;

    /**
     * 获取收款类型
     */
    @GetMapping("/receipt/type")
    public ResponseJson<List<ReceiptType>> getReceiptType() {
        return financeService.getReceiptType();
    }

    /**
     * 获取收款列表
     */
    @GetMapping("/receipt/list")
    public ResponseJson<PaginationVo<ReceiptList>> getReceiptList(ReceiptParam receiptParam,
                                                                  @RequestParam(value = "pageNum", defaultValue = "1") int pageNum,
                                                                  @RequestParam(value = "pageSize", defaultValue = "10") int pageSize) {
        return financeService.getReceiptList(receiptParam, pageNum, pageSize);
    }

    /**
     * 收款详情
     */
    @GetMapping("/receipt/detail")
    public ResponseJson<ReceiptDetail> getReceiptDetail(Integer id) {
        if (null == id) {
            return ResponseJson.error("收款Id不能为空！", null);
        }
        return financeService.getReceiptDetail(id);
    }

}
