package com.caimei365.manager.dao;

import com.caimei365.manager.entity.caimei.*;
import org.apache.ibatis.annotations.Mapper;

import java.util.List;

/**
 * Description
 *
 * @author : Charles
 * @date : 2022/2/23
 */
@Mapper
public interface FinanceDao {
    /**
     * 所有用户
     */
    List<ReceiptUser> getReceiptUsers();
    /**
     * 根据ID获取收款用户
     */
    ReceiptUser getReceiptUserById(Integer id);
    /**
     * 查询是否存在当前手机号的用户
     * @param mobile 手机号
     */
    ReceiptUser getReceiptUserByMobile(String mobile);
    /**
     * 获取收款权限列表
     */
    List<ReceiptPermission> getReceiptPermissions();
    /**
     * 用户权限
     */
    List<ReceiptPermission> getReceiptPermissionsByUserId(Integer userId);
    /**
     * 新增收款用户
     */
    void insertReceiptUser(ReceiptUser receiptUser);
    /**
     * 更新收款用户
     */
    void updateReceiptUser(ReceiptUser receiptUser);
    /**
     * 删除收款用户
     */
    void deleteReceiptUser(Integer id);
    /**
     * 删除收款用户原有权限关联
     */
    void deleteReceiptPermissionRelation(Integer userId);
    /**
     * 新增收款用户权限关联
     */
    void insertReceiptPermissionRelation(Integer userId, Integer permissionId);
    /**
     * 获取收款类型
     */
    List<ReceiptType> getReceiptType();
    /**
     * 获取收款列表
     */
    List<ReceiptList> getReceiptList(ReceiptParam receiptParam);
    /**
     * 收款详情
     */
    ReceiptDetail getReceiptDetail(Integer id);
    /**
     * 收款关联
     */
    List<ReceiptRelation> getReceiptRelations(Integer receiptId);
    /**
     * 收款子订单
     */
    ReceiptOrder getReceiptOrderByShopOrderId(Integer shopOrderId);
    /**
     * 收款主订单
     */
    ReceiptOrder getOrderInfoByOrderId(Integer orderId);
    /**
     * 供应商退款,已退金额
     */
    double getRefundAmountByShopOrder(Integer shopOrderId);
    /**
     * 根据订单Id获取收款记录
     */
    List<ReceiptRecord> getReceiptRecordByOrderId(Integer orderId);
    /**
     * 退款余额金额
     */
    double getReturnBalanceAmount(Integer receiptId);
    /**
     * 统计当前订单已收款
     */
    double getAssociateAmountByOrderId(Integer orderId);
    /**
     * 统计线下余额抵扣
     */
    Double sumUserMoney(Integer orderId);
    /**
     * 统计线上余额抵扣
     */
    Double sumOnlineMoney(Integer orderId);
    /**
     * 关联会员记录
     */
    ReceiptVipInfo getReceiptVipInfo(Integer receiptId);
    /**
     * 关联优惠券购买记录
     */
    ReceiptCouponInfo getReceiptCouponInfo(Integer receiptId);
}
