package com.caimei365.manager.service.caimei.impl;

import com.caimei365.manager.dao.FinanceDao;
import com.caimei365.manager.entity.PaginationVo;
import com.caimei365.manager.entity.ResponseJson;
import com.caimei365.manager.entity.caimei.*;
import com.caimei365.manager.service.caimei.FinanceService;
import com.github.pagehelper.PageHelper;
import lombok.extern.slf4j.Slf4j;
import org.springframework.stereotype.Service;
import org.springframework.util.CollectionUtils;
import org.springframework.util.StringUtils;

import javax.annotation.Resource;
import java.util.ArrayList;
import java.util.List;

/**
 * Description
 *
 * @author : Charles
 * @date : 2022/3/15
 */
 @Slf4j
@Service
public class FinanceServiceImpl implements FinanceService {
    @Resource
    private FinanceDao financeDao;

    /**
     * 获取收款类型
     */
    @Override
    public ResponseJson<List<ReceiptType>> getReceiptType() {
        List<ReceiptType> list = financeDao.getReceiptType();
        return ResponseJson.success(list);
    }

    /**
     * 获取收款列表
     */
    @Override
    public ResponseJson<PaginationVo<ReceiptList>> getReceiptList(ReceiptParam receiptParam, int pageNum, int pageSize) {
        if (StringUtils.hasLength(receiptParam.getStartTime())) {
            String startTime = receiptParam.getStartTime().substring(0, 10) + " 00:00:00";
            receiptParam.setStartTime(startTime);
        }
        if (StringUtils.hasLength(receiptParam.getEndTime())) {
            String endTime = receiptParam.getEndTime().substring(0, 10) + " 23:59:59";
            receiptParam.setEndTime(endTime);
        }
        PageHelper.startPage(pageNum, pageSize);
        List<ReceiptList> receiptList = financeDao.getReceiptList(receiptParam);
        PaginationVo<ReceiptList> pageData = new PaginationVo<>(receiptList);
        return ResponseJson.success(pageData);
    }

    /**
     * 收款详情
     */
    @Override
    public ResponseJson<ReceiptDetail> getReceiptDetail(Integer id) {
        ReceiptDetail receipt = financeDao.getReceiptDetail(id);
        List<ReceiptRelation> relations = financeDao.getReceiptRelations(id);
        if (!CollectionUtils.isEmpty(relations) && relations.size() > 1) {
            receipt.setReceiptOrderFlag(true);
        }
        // 一个收款可能会关联了一个或多个订单
        List<ReceiptOrder> orderInfos = new ArrayList<>();
        for (ReceiptRelation relation : relations) {
            ReceiptOrder roi = null;
            if (2 == relation.getRelationType() {
                // relationType==2时，orderId为主订单Id
                roi = financeDao.getOrderInfoByOrderId(relation.getOrderId());
            }
            if (1 == relation.getRelationType()) {
                // relationType==1时，orderId为子订单Id
                roi = financeDao.getReceiptOrderByShopOrderId(relation.getOrderId());
                if (null != roi) {
                    if (5 == receipt.getReceiptType()) {
                        // 供应商退款,已退金额
                        double refundAmount = financeDao.getRefundAmountByShopOrder(roi.getShopOrderId());
                        roi.setRefundsAmount(refundAmount);
                    }
                }
            }
            if (null != roi) {
                roi.setRelationType(relation.getRelationType());
                // 根据订单Id获取收款记录
                List<ReceiptRecord> recordList = financeDao.getReceiptRecordByOrderId(roi.getOrderId());
                // 暂时不启用抹平明细
                if (!CollectionUtils.isEmpty(recordList)) {
                    for (ReceiptRecord record : recordList) {
                        if (3 == record.getConfirmType()) {
                            double returnBalanceAmount = financeDao.getReturnBalanceAmount(record.getReceiptId());
                            record.setReturnBalanceAmount(returnBalanceAmount);
                        }
                        // 统计当前已收
                        double associateAmount = financeDao.getAssociateAmountByOrderId(roi.getOrderId());
                        record.setOrderReceivedAmount(associateAmount);
                        if (16 == receipt.getPayType()) {
                            Double userMoney = financeDao.sumUserMoney(roi.getOrderId());
                            Double onlineMoney = financeDao.sumOnlineMoney(roi.getOrderId());
                            if (null == onlineMoney) {
                                record.setOnlineMoney(0d);
                            } else {
                                record.setOnlineMoney(onlineMoney);
                            }
                            if (null == userMoney) {
                                record.setUserMoney(0d);
                            } else {
                                record.setUserMoney(userMoney);
                            }
                        }
                    }
                }
                //一个订单又包含了多个收款记录
                roi.setReceiptRecords(recordList);
                orderInfos.add(roi);
            }
        }
        receipt.setOrderInfos(orderInfos);

        if (6 == receipt.getReceiptType()) {
            // 3超级会员款
            ReceiptVipInfo receiptVipInfo = financeDao.getReceiptVipInfo(receipt.getId());
            receipt.setVipInfo(receiptVipInfo);
        }
        if (8 == receipt.getReceiptType()) {
            //优惠券购买费
            ReceiptCouponInfo couponInfo = financeDao.getReceiptCouponInfo(receipt.getId());
            receipt.setCouponInfo(couponInfo);
        }

        return ResponseJson.success(receipt);
    }
}
